# swagger-java-client

## Requirements

Building the API client library requires [Maven](https://maven.apache.org/) to be installed.

## Installation

To install the API client library to your local Maven repository, simply execute:

```shell
mvn install
```

To deploy it to a remote Maven repository instead, configure the settings of the repository and execute:

```shell
mvn deploy
```

Refer to the [official documentation](https://maven.apache.org/plugins/maven-deploy-plugin/usage.html) for more information.

### Maven users

Add this dependency to your project's POM:

```xml
<dependency>
    <groupId>io.swagger</groupId>
    <artifactId>swagger-java-client</artifactId>
    <version>1.0.0</version>
    <scope>compile</scope>
</dependency>
```

### Gradle users

Add this dependency to your project's build file:

```groovy
compile "io.swagger:swagger-java-client:1.0.0"
```

### Others

At first generate the JAR by executing:

    mvn package

Then manually install the following JARs:

* target/swagger-java-client-1.0.0.jar
* target/lib/*.jar

## Getting Started

Please follow the [installation](#installation) instruction and execute the following Java code:

```java

import io.swagger.client.*;
import io.swagger.client.auth.*;
import io.swagger.client.model.*;
import io.swagger.client.api.APIHealthApi;

import java.io.File;
import java.util.*;

public class APIHealthApiExample {

    public static void main(String[] args) {
        
        APIHealthApi apiInstance = new APIHealthApi();
        try {
            BaseResponseOfMapOfstringAndstring result = apiInstance.healthCheckUsingGET();
            System.out.println(result);
        } catch (ApiException e) {
            System.err.println("Exception when calling APIHealthApi#healthCheckUsingGET");
            e.printStackTrace();
        }
    }
}

```

## Documentation for API Endpoints

All URIs are relative to *https://h.app.wdesk.com/s/wdata/prep*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*APIHealthApi* | [**healthCheckUsingGET**](docs/APIHealthApi.md#healthCheckUsingGET) | **GET** /health | Health check
*AdministrativeTasksApi* | [**deleteWorkspaceUsingDELETE**](docs/AdministrativeTasksApi.md#deleteWorkspaceUsingDELETE) | **DELETE** /api/v1/admin/account | Delete a single workspace
*AdministrativeTasksApi* | [**exportWorkspaceUsingGET**](docs/AdministrativeTasksApi.md#exportWorkspaceUsingGET) | **GET** /api/v1/admin/export | Export a single workspace
*AdministrativeTasksApi* | [**findWorkspaceFilesBySizeUsingGET**](docs/AdministrativeTasksApi.md#findWorkspaceFilesBySizeUsingGET) | **GET** /api/v1/admin/usage/filesBySize | Retrieve workspace files by size
*AdministrativeTasksApi* | [**getWorkspaceQueryUsageUsingGET**](docs/AdministrativeTasksApi.md#getWorkspaceQueryUsageUsingGET) | **GET** /api/v1/admin/usage/query | Retrieve workspace query usage
*AdministrativeTasksApi* | [**getWorkspaceUploadUsageUsingGET**](docs/AdministrativeTasksApi.md#getWorkspaceUploadUsageUsingGET) | **GET** /api/v1/admin/usage/upload | Retrieve workspace upload usage
*AdministrativeTasksApi* | [**importDataUsingPOST**](docs/AdministrativeTasksApi.md#importDataUsingPOST) | **POST** /api/v1/admin/import | Import data
*AdministrativeTasksApi* | [**validateFilesUsingPOST**](docs/AdministrativeTasksApi.md#validateFilesUsingPOST) | **POST** /api/v1/admin/validation/files | Validate files
*AdministrativeTasksApi* | [**validateTablesUsingPOST**](docs/AdministrativeTasksApi.md#validateTablesUsingPOST) | **POST** /api/v1/admin/validation/tables | Validate tables
*ConnectionManagementApi* | [**getConnectionUsingGET**](docs/ConnectionManagementApi.md#getConnectionUsingGET) | **GET** /api/v1/connections/{connectionId} | Get connection details
*ConnectionManagementApi* | [**getRefreshBatchStatusUsingGET**](docs/ConnectionManagementApi.md#getRefreshBatchStatusUsingGET) | **GET** /api/v1/connections/batch/refresh/{batchId} | Gets the status of a batch refresh
*ConnectionManagementApi* | [**getRefreshStatusUsingGET**](docs/ConnectionManagementApi.md#getRefreshStatusUsingGET) | **GET** /api/v1/connections/{connectionId}/status | Get connection refresh status
*ConnectionManagementApi* | [**listConnectionsUsingGET**](docs/ConnectionManagementApi.md#listConnectionsUsingGET) | **GET** /api/v1/connections | List connections
*ConnectionManagementApi* | [**refreshBatchUsingPOST**](docs/ConnectionManagementApi.md#refreshBatchUsingPOST) | **POST** /api/v1/connections/batch/refresh | Refresh batch of connections
*ConnectionManagementApi* | [**refreshConnectionUsingPOST**](docs/ConnectionManagementApi.md#refreshConnectionUsingPOST) | **POST** /api/v1/connections/{connectionId}/refresh | Refresh connection
*FileManagementApi* | [**deleteFileUsingDELETE**](docs/FileManagementApi.md#deleteFileUsingDELETE) | **DELETE** /api/v1/file/{fileId} | Delete a single file
*FileManagementApi* | [**downloadFileUsingGET**](docs/FileManagementApi.md#downloadFileUsingGET) | **GET** /api/v1/file/{fileId}/download | Download a single file
*FileManagementApi* | [**exportFileToSpreadsheetsUsingPOST**](docs/FileManagementApi.md#exportFileToSpreadsheetsUsingPOST) | **POST** /api/v1/file/{fileId}/export | Export a file to spreadsheets
*FileManagementApi* | [**getErrorsUsingGET**](docs/FileManagementApi.md#getErrorsUsingGET) | **GET** /api/v1/file/{fileId}/error | Retrieve errors
*FileManagementApi* | [**getFileUsingGET**](docs/FileManagementApi.md#getFileUsingGET) | **GET** /api/v1/file/{fileId} | Retrieve a single file
*FileManagementApi* | [**getFilesUsingGET**](docs/FileManagementApi.md#getFilesUsingGET) | **GET** /api/v1/file | Retrieve a list of files
*FileManagementApi* | [**uploadFileUsingPOST**](docs/FileManagementApi.md#uploadFileUsingPOST) | **POST** /api/v1/file | Upload a single file
*FileManagementApi* | [**validateFilenameUsingGET**](docs/FileManagementApi.md#validateFilenameUsingGET) | **GET** /api/v1/file/validateName | Validate whether a file with the filename can be uploaded to the table
*FolderManagementApi* | [**createFolderUsingPOST**](docs/FolderManagementApi.md#createFolderUsingPOST) | **POST** /api/v1/folder | Create a new folder
*FolderManagementApi* | [**deleteFolderUsingDELETE**](docs/FolderManagementApi.md#deleteFolderUsingDELETE) | **DELETE** /api/v1/folder/{folderId} | Delete a single folder
*FolderManagementApi* | [**getFolderUsingGET**](docs/FolderManagementApi.md#getFolderUsingGET) | **GET** /api/v1/folder/{folderId} | Retrieve a single folder
*FolderManagementApi* | [**listChildrenUsingGET**](docs/FolderManagementApi.md#listChildrenUsingGET) | **GET** /api/v1/folder/{folderId}/children | Retrieve list of folder contents
*FolderManagementApi* | [**listFoldersUsingGET**](docs/FolderManagementApi.md#listFoldersUsingGET) | **GET** /api/v1/folder | Retrieve a list of folders
*FolderManagementApi* | [**searchUsingGET**](docs/FolderManagementApi.md#searchUsingGET) | **GET** /api/v1/entity | Search
*FolderManagementApi* | [**setChildrenUsingPOST**](docs/FolderManagementApi.md#setChildrenUsingPOST) | **POST** /api/v1/folder/{folderId}/children | Move content into a folder
*FolderManagementApi* | [**updateFolderUsingPUT**](docs/FolderManagementApi.md#updateFolderUsingPUT) | **PUT** /api/v1/folder/{folderId} | Update a single folder
*ParameterManagementApi* | [**createParameterUsingPOST**](docs/ParameterManagementApi.md#createParameterUsingPOST) | **POST** /api/v1/parameter | Create parameter
*ParameterManagementApi* | [**deleteParameterUsingDELETE**](docs/ParameterManagementApi.md#deleteParameterUsingDELETE) | **DELETE** /api/v1/parameter/{parameterId} | Delete Parameter
*ParameterManagementApi* | [**getParameterUsingGET**](docs/ParameterManagementApi.md#getParameterUsingGET) | **GET** /api/v1/parameter/{parameterId} | Get Parameter
*ParameterManagementApi* | [**listParametersUsingGET**](docs/ParameterManagementApi.md#listParametersUsingGET) | **GET** /api/v1/parameter | Get Parameters
*ParameterManagementApi* | [**updateParameterUsingPUT**](docs/ParameterManagementApi.md#updateParameterUsingPUT) | **PUT** /api/v1/parameter/{parameterId} | Update Parameter
*PivotViewManagementApi* | [**createPivotViewUsingPOST**](docs/PivotViewManagementApi.md#createPivotViewUsingPOST) | **POST** /api/v1/pivotview | Create a new pivot view
*PivotViewManagementApi* | [**deletePivotViewUsingDELETE**](docs/PivotViewManagementApi.md#deletePivotViewUsingDELETE) | **DELETE** /api/v1/pivotview/{pivotViewId} | Delete a single pivot view
*PivotViewManagementApi* | [**downloadPivotViewTokenUsingGET**](docs/PivotViewManagementApi.md#downloadPivotViewTokenUsingGET) | **GET** /api/v1/pivotview/{pivotViewId}/token | This endpoint is deprecated. It not longer functions as intended, as pivotingquery results is now handled by cross tab queries. This endpoint will be removedon September 1, 2020.
*PivotViewManagementApi* | [**downloadPivotViewUsingGET**](docs/PivotViewManagementApi.md#downloadPivotViewUsingGET) | **GET** /api/v1/pivotview/{pivotViewId}/download | This endpoint is deprecated. It not longer functions as intended, as pivotingquery results is now handled by cross tab queries. This endpoint will be removedon September 1, 2020.
*PivotViewManagementApi* | [**getPivotViewUsingGET**](docs/PivotViewManagementApi.md#getPivotViewUsingGET) | **GET** /api/v1/pivotview/{pivotViewId} | Retrieve a single pivot view
*PivotViewManagementApi* | [**listPivotViewsUsingGET**](docs/PivotViewManagementApi.md#listPivotViewsUsingGET) | **GET** /api/v1/pivotview | Retrieve a list of pivot views
*PivotViewManagementApi* | [**updatePivotViewUsingPUT**](docs/PivotViewManagementApi.md#updatePivotViewUsingPUT) | **PUT** /api/v1/pivotview/{pivotViewId} | Update a single pivot view
*QueryManagementApi* | [**cancelQueryUsingDELETE**](docs/QueryManagementApi.md#cancelQueryUsingDELETE) | **DELETE** /api/v1/queryresult/{queryResultId} | Cancel a running query
*QueryManagementApi* | [**createQueryUsingPOST**](docs/QueryManagementApi.md#createQueryUsingPOST) | **POST** /api/v1/query | Create a new query
*QueryManagementApi* | [**deleteQueryUsingDELETE**](docs/QueryManagementApi.md#deleteQueryUsingDELETE) | **DELETE** /api/v1/query/{queryId} | Delete a single query
*QueryManagementApi* | [**downloadQueryResultUsingGET**](docs/QueryManagementApi.md#downloadQueryResultUsingGET) | **GET** /api/v1/queryresult/{queryResultId}/download | Download a query result
*QueryManagementApi* | [**exportQueryResultToSpreadsheetsUsingPOST**](docs/QueryManagementApi.md#exportQueryResultToSpreadsheetsUsingPOST) | **POST** /api/v1/queryresult/{queryResultId}/export | Export query result to spreadsheets
*QueryManagementApi* | [**getDependenciesUsingGET**](docs/QueryManagementApi.md#getDependenciesUsingGET) | **GET** /api/v1/query/{queryId}/dependencies | Retrieve dependencies
*QueryManagementApi* | [**getQueryColumnDataUsingPOST**](docs/QueryManagementApi.md#getQueryColumnDataUsingPOST) | **POST** /api/v1/query/data | Retrieve query column data
*QueryManagementApi* | [**getQueryResultUsingGET**](docs/QueryManagementApi.md#getQueryResultUsingGET) | **GET** /api/v1/queryresult/{queryResultId} | Retrieve a single query result
*QueryManagementApi* | [**getQueryUsingGET**](docs/QueryManagementApi.md#getQueryUsingGET) | **GET** /api/v1/query/{queryId} | Retrieve a single query
*QueryManagementApi* | [**getTablesDependentOnQueryUsingGET**](docs/QueryManagementApi.md#getTablesDependentOnQueryUsingGET) | **GET** /api/v1/query/{queryId}/dependents | Retrieve a list of dependents
*QueryManagementApi* | [**isQueryValidUsingPOST**](docs/QueryManagementApi.md#isQueryValidUsingPOST) | **POST** /api/v1/query/validation | Parses the query to determine if it is valid
*QueryManagementApi* | [**listQueriesUsingGET**](docs/QueryManagementApi.md#listQueriesUsingGET) | **GET** /api/v1/query | Retrieve list of queries
*QueryManagementApi* | [**listQueryResultsUsingGET**](docs/QueryManagementApi.md#listQueryResultsUsingGET) | **GET** /api/v1/queryresult | Retrieve a list of query results
*QueryManagementApi* | [**previewQueryUsingPOST**](docs/QueryManagementApi.md#previewQueryUsingPOST) | **POST** /api/v1/query/preview/{tableId} | Preview a query
*QueryManagementApi* | [**runQueryUsingPOST**](docs/QueryManagementApi.md#runQueryUsingPOST) | **POST** /api/v1/queryresult | Execute a query
*QueryManagementApi* | [**updateQueryUsingPUT**](docs/QueryManagementApi.md#updateQueryUsingPUT) | **PUT** /api/v1/query/{queryId} | Update a single query
*SelectListManagementApi* | [**createSelectListUsingPOST**](docs/SelectListManagementApi.md#createSelectListUsingPOST) | **POST** /api/v1/selectlist | Create a new select list
*SelectListManagementApi* | [**deleteUsingDELETE**](docs/SelectListManagementApi.md#deleteUsingDELETE) | **DELETE** /api/v1/selectlist/{selectListId} | Delete a single select list
*SelectListManagementApi* | [**getSelectListUsingGET**](docs/SelectListManagementApi.md#getSelectListUsingGET) | **GET** /api/v1/selectlist/{selectListId} | Retrieve a single select list
*SelectListManagementApi* | [**listSelectListsUsingGET**](docs/SelectListManagementApi.md#listSelectListsUsingGET) | **GET** /api/v1/selectlist | Retrieve a list of select lists
*SelectListManagementApi* | [**updateSelectListUsingPUT**](docs/SelectListManagementApi.md#updateSelectListUsingPUT) | **PUT** /api/v1/selectlist/{selectListId} | Update a single select list
*SharedTableManagementApi* | [**createSharedTableUsingPOST**](docs/SharedTableManagementApi.md#createSharedTableUsingPOST) | **POST** /api/v1/sharedtable | Create a new shared table
*SharedTableManagementApi* | [**deleteSharedTableUsingDELETE**](docs/SharedTableManagementApi.md#deleteSharedTableUsingDELETE) | **DELETE** /api/v1/sharedtable/{sharedTableId} | Delete a single shared table
*SharedTableManagementApi* | [**getSharedTableUsingGET**](docs/SharedTableManagementApi.md#getSharedTableUsingGET) | **GET** /api/v1/sharedtable/{sharedTableId} | Retrieve a single shared table
*SharedTableManagementApi* | [**listSharedTablesUsingGET**](docs/SharedTableManagementApi.md#listSharedTablesUsingGET) | **GET** /api/v1/sharedtable | Retrieve a list of shared tables
*TableManagementApi* | [**createTableUsingPOST**](docs/TableManagementApi.md#createTableUsingPOST) | **POST** /api/v1/table | Create a new table
*TableManagementApi* | [**deleteTableUsingDELETE**](docs/TableManagementApi.md#deleteTableUsingDELETE) | **DELETE** /api/v1/table/{tableId} | Delete a single table
*TableManagementApi* | [**getDependentsUsingGET**](docs/TableManagementApi.md#getDependentsUsingGET) | **GET** /api/v1/table/{tableId}/dependents | Retrieve a list of dependents
*TableManagementApi* | [**getImportInfoUsingGET**](docs/TableManagementApi.md#getImportInfoUsingGET) | **GET** /api/v1/table/{tableId}/importInfo | Retrieve import information
*TableManagementApi* | [**getTableUsingGET**](docs/TableManagementApi.md#getTableUsingGET) | **GET** /api/v1/table/{tableId} | Retrieve a single table
*TableManagementApi* | [**getTablesUsingGET**](docs/TableManagementApi.md#getTablesUsingGET) | **GET** /api/v1/table | Retrieve a list of tables
*TableManagementApi* | [**importFileUsingPOST**](docs/TableManagementApi.md#importFileUsingPOST) | **POST** /api/v1/table/{tableId}/import | Import a single file
*TableManagementApi* | [**importFromSpreadsheetsUsingPOST**](docs/TableManagementApi.md#importFromSpreadsheetsUsingPOST) | **POST** /api/v1/table/{tableId}/spreadsheet/import | Import from spreadsheets
*TableManagementApi* | [**unimportFileUsingDELETE**](docs/TableManagementApi.md#unimportFileUsingDELETE) | **DELETE** /api/v1/table/{tableId}/import/{fileId} | Unimport a single file
*TableManagementApi* | [**updateTableUsingPUT**](docs/TableManagementApi.md#updateTableUsingPUT) | **PUT** /api/v1/table/{tableId} | Update a single table
*TagManagementApi* | [**createTagUsingPOST**](docs/TagManagementApi.md#createTagUsingPOST) | **POST** /api/v1/tag | Create a new tag
*TagManagementApi* | [**deleteTagUsingDELETE**](docs/TagManagementApi.md#deleteTagUsingDELETE) | **DELETE** /api/v1/tag/{tagId} | Delete a single tag
*TagManagementApi* | [**listTagsUsingGET**](docs/TagManagementApi.md#listTagsUsingGET) | **GET** /api/v1/tag | Retrieve a list of tags
*TagManagementApi* | [**updateTagUsingPUT**](docs/TagManagementApi.md#updateTagUsingPUT) | **PUT** /api/v1/tag/{tagId} | Update a single tag
*TokenManagementApi* | [**createTokenUsingPOST**](docs/TokenManagementApi.md#createTokenUsingPOST) | **POST** /api/v1/token | Create a new token
*TokenManagementApi* | [**downloadFileUsingGET1**](docs/TokenManagementApi.md#downloadFileUsingGET1) | **GET** /api/v1/token/{tokenId} | Download a single file
*UtilitiesApi* | [**parseDateUsingPOST**](docs/UtilitiesApi.md#parseDateUsingPOST) | **POST** /api/v1/util/datetime | Parse a date


## Documentation for Models

 - [BaseResponseOfCollectionOfFolderableDto](docs/BaseResponseOfCollectionOfFolderableDto.md)
 - [BaseResponseOfConnectionDto](docs/BaseResponseOfConnectionDto.md)
 - [BaseResponseOfConnectionRunDto](docs/BaseResponseOfConnectionRunDto.md)
 - [BaseResponseOfFileMetaDto](docs/BaseResponseOfFileMetaDto.md)
 - [BaseResponseOfFolderDto](docs/BaseResponseOfFolderDto.md)
 - [BaseResponseOfGlobalParameterDto](docs/BaseResponseOfGlobalParameterDto.md)
 - [BaseResponseOfImportInfoDto](docs/BaseResponseOfImportInfoDto.md)
 - [BaseResponseOfMapOfstringAndstring](docs/BaseResponseOfMapOfstringAndstring.md)
 - [BaseResponseOfPivotViewDto](docs/BaseResponseOfPivotViewDto.md)
 - [BaseResponseOfQueryColumnDataDto](docs/BaseResponseOfQueryColumnDataDto.md)
 - [BaseResponseOfQueryDto](docs/BaseResponseOfQueryDto.md)
 - [BaseResponseOfQueryResultDto](docs/BaseResponseOfQueryResultDto.md)
 - [BaseResponseOfRefreshBatchDto](docs/BaseResponseOfRefreshBatchDto.md)
 - [BaseResponseOfSelectListDto](docs/BaseResponseOfSelectListDto.md)
 - [BaseResponseOfSharedTableDto](docs/BaseResponseOfSharedTableDto.md)
 - [BaseResponseOfSpreadsheetInfoDto](docs/BaseResponseOfSpreadsheetInfoDto.md)
 - [BaseResponseOfTableDto](docs/BaseResponseOfTableDto.md)
 - [BaseResponseOfTagDto](docs/BaseResponseOfTagDto.md)
 - [BaseResponseOfTokenDto](docs/BaseResponseOfTokenDto.md)
 - [BaseResponseOfValidateFilesDto](docs/BaseResponseOfValidateFilesDto.md)
 - [BaseResponseOfValidateTablesDto](docs/BaseResponseOfValidateTablesDto.md)
 - [BaseResponseOflong](docs/BaseResponseOflong.md)
 - [BaseResponseOfstring](docs/BaseResponseOfstring.md)
 - [Column](docs/Column.md)
 - [ColumnDto](docs/ColumnDto.md)
 - [ColumnInfoDto](docs/ColumnInfoDto.md)
 - [ConnectionDto](docs/ConnectionDto.md)
 - [ConnectionRunDto](docs/ConnectionRunDto.md)
 - [DatetimeDto](docs/DatetimeDto.md)
 - [ExportFileDto](docs/ExportFileDto.md)
 - [ExportQueryResultDto](docs/ExportQueryResultDto.md)
 - [FileMetaDto](docs/FileMetaDto.md)
 - [FolderDto](docs/FolderDto.md)
 - [FolderableDto](docs/FolderableDto.md)
 - [GlobalParameterDto](docs/GlobalParameterDto.md)
 - [ImportDto](docs/ImportDto.md)
 - [ImportErrorDto](docs/ImportErrorDto.md)
 - [ImportFromSpreadsheetDto](docs/ImportFromSpreadsheetDto.md)
 - [ImportInfoDto](docs/ImportInfoDto.md)
 - [MapOfstringAndobject](docs/MapOfstringAndobject.md)
 - [MapOfstringAndstring](docs/MapOfstringAndstring.md)
 - [MultiError](docs/MultiError.md)
 - [PagedResponseOfConnectionDto](docs/PagedResponseOfConnectionDto.md)
 - [PagedResponseOfFileMetaDto](docs/PagedResponseOfFileMetaDto.md)
 - [PagedResponseOfFolderDto](docs/PagedResponseOfFolderDto.md)
 - [PagedResponseOfFolderableDto](docs/PagedResponseOfFolderableDto.md)
 - [PagedResponseOfGlobalParameterDto](docs/PagedResponseOfGlobalParameterDto.md)
 - [PagedResponseOfImportErrorDto](docs/PagedResponseOfImportErrorDto.md)
 - [PagedResponseOfPivotViewDto](docs/PagedResponseOfPivotViewDto.md)
 - [PagedResponseOfQueryDto](docs/PagedResponseOfQueryDto.md)
 - [PagedResponseOfQueryResultDto](docs/PagedResponseOfQueryResultDto.md)
 - [PagedResponseOfSelectListDto](docs/PagedResponseOfSelectListDto.md)
 - [PagedResponseOfSharedTableDto](docs/PagedResponseOfSharedTableDto.md)
 - [PagedResponseOfTableDto](docs/PagedResponseOfTableDto.md)
 - [PagedResponseOfTagDto](docs/PagedResponseOfTagDto.md)
 - [PivotDefinitionDto](docs/PivotDefinitionDto.md)
 - [PivotViewDefinitionColumnDto](docs/PivotViewDefinitionColumnDto.md)
 - [PivotViewDefinitionFilterDto](docs/PivotViewDefinitionFilterDto.md)
 - [PivotViewDefinitionRowDto](docs/PivotViewDefinitionRowDto.md)
 - [PivotViewDefinitionValueDto](docs/PivotViewDefinitionValueDto.md)
 - [PivotViewDto](docs/PivotViewDto.md)
 - [QueryColumnDataDto](docs/QueryColumnDataDto.md)
 - [QueryDependencyDto](docs/QueryDependencyDto.md)
 - [QueryDto](docs/QueryDto.md)
 - [QueryParameterDto](docs/QueryParameterDto.md)
 - [QueryResultDto](docs/QueryResultDto.md)
 - [QueryTextDto](docs/QueryTextDto.md)
 - [RefreshBatchDto](docs/RefreshBatchDto.md)
 - [RefreshConnectionDto](docs/RefreshConnectionDto.md)
 - [SelectListDto](docs/SelectListDto.md)
 - [SharedTableDto](docs/SharedTableDto.md)
 - [SingleError](docs/SingleError.md)
 - [SpreadsheetInfoDto](docs/SpreadsheetInfoDto.md)
 - [StartValidateFilesDto](docs/StartValidateFilesDto.md)
 - [TableDto](docs/TableDto.md)
 - [TableSchema](docs/TableSchema.md)
 - [TagDto](docs/TagDto.md)
 - [TokenDto](docs/TokenDto.md)
 - [UniqueConstraintDto](docs/UniqueConstraintDto.md)
 - [ValidateFilesDto](docs/ValidateFilesDto.md)
 - [ValidateTablesDto](docs/ValidateTablesDto.md)


## Documentation for Authorization

Authentication schemes defined for the API:
### oauth

- **Type**: OAuth
- **Flow**: application
- **Authorizatoin URL**: 
- **Scopes**: N/A


## Recommendation

It's recommended to create an instance of `ApiClient` per thread in a multithreaded environment to avoid any potential issue.

## Author

platformsupport@workiva.com

