# TableManagementApi

All URIs are relative to *https://h.app.wdesk.com/s/wdata/prep*

Method | HTTP request | Description
------------- | ------------- | -------------
[**createTableUsingPOST**](TableManagementApi.md#createTableUsingPOST) | **POST** /api/v1/table | Create a new table
[**deleteTableUsingDELETE**](TableManagementApi.md#deleteTableUsingDELETE) | **DELETE** /api/v1/table/{tableId} | Delete a single table
[**getDependentsUsingGET**](TableManagementApi.md#getDependentsUsingGET) | **GET** /api/v1/table/{tableId}/dependents | Retrieve a list of dependents
[**getImportInfoUsingGET**](TableManagementApi.md#getImportInfoUsingGET) | **GET** /api/v1/table/{tableId}/importInfo | Retrieve import information
[**getTableUsingGET**](TableManagementApi.md#getTableUsingGET) | **GET** /api/v1/table/{tableId} | Retrieve a single table
[**getTablesUsingGET**](TableManagementApi.md#getTablesUsingGET) | **GET** /api/v1/table | Retrieve a list of tables
[**importFileUsingPOST**](TableManagementApi.md#importFileUsingPOST) | **POST** /api/v1/table/{tableId}/import | Import a single file
[**importFromSpreadsheetsUsingPOST**](TableManagementApi.md#importFromSpreadsheetsUsingPOST) | **POST** /api/v1/table/{tableId}/spreadsheet/import | Import from spreadsheets
[**unimportFileUsingDELETE**](TableManagementApi.md#unimportFileUsingDELETE) | **DELETE** /api/v1/table/{tableId}/import/{fileId} | Unimport a single file
[**updateTableUsingPUT**](TableManagementApi.md#updateTableUsingPUT) | **PUT** /api/v1/table/{tableId} | Update a single table


<a name="createTableUsingPOST"></a>
# **createTableUsingPOST**
> BaseResponseOfTableDto createTableUsingPOST(body)

Create a new table

Creates a table in the database with the specified schema. For type, specify either a dimension or data table. In the interface, data tables appear as fact tables.

### Example
```java
// Import classes:
//import io.swagger.client.ApiClient;
//import io.swagger.client.ApiException;
//import io.swagger.client.Configuration;
//import io.swagger.client.auth.*;
//import io.swagger.client.api.TableManagementApi;

ApiClient defaultClient = Configuration.getDefaultApiClient();

// Configure OAuth2 access token for authorization: oauth
OAuth oauth = (OAuth) defaultClient.getAuthentication("oauth");
oauth.setAccessToken("YOUR ACCESS TOKEN");

TableManagementApi apiInstance = new TableManagementApi();
TableDto body = new TableDto(); // TableDto | The representation of the table to create
try {
    BaseResponseOfTableDto result = apiInstance.createTableUsingPOST(body);
    System.out.println(result);
} catch (ApiException e) {
    System.err.println("Exception when calling TableManagementApi#createTableUsingPOST");
    e.printStackTrace();
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **body** | [**TableDto**](TableDto.md)| The representation of the table to create |

### Return type

[**BaseResponseOfTableDto**](BaseResponseOfTableDto.md)

### Authorization

[oauth](../README.md#oauth)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

<a name="deleteTableUsingDELETE"></a>
# **deleteTableUsingDELETE**
> BaseResponseOfstring deleteTableUsingDELETE(tableId)

Delete a single table

Soft-deletes the table with the provided ID.

### Example
```java
// Import classes:
//import io.swagger.client.ApiClient;
//import io.swagger.client.ApiException;
//import io.swagger.client.Configuration;
//import io.swagger.client.auth.*;
//import io.swagger.client.api.TableManagementApi;

ApiClient defaultClient = Configuration.getDefaultApiClient();

// Configure OAuth2 access token for authorization: oauth
OAuth oauth = (OAuth) defaultClient.getAuthentication("oauth");
oauth.setAccessToken("YOUR ACCESS TOKEN");

TableManagementApi apiInstance = new TableManagementApi();
String tableId = "tableId_example"; // String | The unique identifier of the table
try {
    BaseResponseOfstring result = apiInstance.deleteTableUsingDELETE(tableId);
    System.out.println(result);
} catch (ApiException e) {
    System.err.println("Exception when calling TableManagementApi#deleteTableUsingDELETE");
    e.printStackTrace();
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **tableId** | **String**| The unique identifier of the table |

### Return type

[**BaseResponseOfstring**](BaseResponseOfstring.md)

### Authorization

[oauth](../README.md#oauth)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

<a name="getDependentsUsingGET"></a>
# **getDependentsUsingGET**
> PagedResponseOfQueryDto getDependentsUsingGET(tableId, limit, cursor, offset)

Retrieve a list of dependents

Returns a list of all queries that use the table with provided ID as a datasource. If a shared table, this may include queries outside of the current OAuth context.  Permission is checked only for the table ID provided, _not_ on the returned list of queries.

### Example
```java
// Import classes:
//import io.swagger.client.ApiClient;
//import io.swagger.client.ApiException;
//import io.swagger.client.Configuration;
//import io.swagger.client.auth.*;
//import io.swagger.client.api.TableManagementApi;

ApiClient defaultClient = Configuration.getDefaultApiClient();

// Configure OAuth2 access token for authorization: oauth
OAuth oauth = (OAuth) defaultClient.getAuthentication("oauth");
oauth.setAccessToken("YOUR ACCESS TOKEN");

TableManagementApi apiInstance = new TableManagementApi();
String tableId = "tableId_example"; // String | The unique identifier of the table
Integer limit = 56; // Integer | The number of folders to return, from 1 to 1000; by default, 1000
String cursor = "cursor_example"; // String | A paging cursor; if included, `limit` is ignored
Long offset = 789L; // Long | The item to start with on the page, greater than or equal to 0; by default, 0
try {
    PagedResponseOfQueryDto result = apiInstance.getDependentsUsingGET(tableId, limit, cursor, offset);
    System.out.println(result);
} catch (ApiException e) {
    System.err.println("Exception when calling TableManagementApi#getDependentsUsingGET");
    e.printStackTrace();
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **tableId** | **String**| The unique identifier of the table |
 **limit** | **Integer**| The number of folders to return, from 1 to 1000; by default, 1000 | [optional]
 **cursor** | **String**| A paging cursor; if included, &#x60;limit&#x60; is ignored | [optional]
 **offset** | **Long**| The item to start with on the page, greater than or equal to 0; by default, 0 | [optional]

### Return type

[**PagedResponseOfQueryDto**](PagedResponseOfQueryDto.md)

### Authorization

[oauth](../README.md#oauth)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

<a name="getImportInfoUsingGET"></a>
# **getImportInfoUsingGET**
> BaseResponseOfImportInfoDto getImportInfoUsingGET(tableId)

Retrieve import information

Returns information around imported files for a table.

### Example
```java
// Import classes:
//import io.swagger.client.ApiClient;
//import io.swagger.client.ApiException;
//import io.swagger.client.Configuration;
//import io.swagger.client.auth.*;
//import io.swagger.client.api.TableManagementApi;

ApiClient defaultClient = Configuration.getDefaultApiClient();

// Configure OAuth2 access token for authorization: oauth
OAuth oauth = (OAuth) defaultClient.getAuthentication("oauth");
oauth.setAccessToken("YOUR ACCESS TOKEN");

TableManagementApi apiInstance = new TableManagementApi();
String tableId = "tableId_example"; // String | The unique identifier of the table
try {
    BaseResponseOfImportInfoDto result = apiInstance.getImportInfoUsingGET(tableId);
    System.out.println(result);
} catch (ApiException e) {
    System.err.println("Exception when calling TableManagementApi#getImportInfoUsingGET");
    e.printStackTrace();
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **tableId** | **String**| The unique identifier of the table |

### Return type

[**BaseResponseOfImportInfoDto**](BaseResponseOfImportInfoDto.md)

### Authorization

[oauth](../README.md#oauth)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

<a name="getTableUsingGET"></a>
# **getTableUsingGET**
> BaseResponseOfTableDto getTableUsingGET(tableId)

Retrieve a single table

Returns a table with the provided ID, or a 404 if no such table is found.

### Example
```java
// Import classes:
//import io.swagger.client.ApiClient;
//import io.swagger.client.ApiException;
//import io.swagger.client.Configuration;
//import io.swagger.client.auth.*;
//import io.swagger.client.api.TableManagementApi;

ApiClient defaultClient = Configuration.getDefaultApiClient();

// Configure OAuth2 access token for authorization: oauth
OAuth oauth = (OAuth) defaultClient.getAuthentication("oauth");
oauth.setAccessToken("YOUR ACCESS TOKEN");

TableManagementApi apiInstance = new TableManagementApi();
String tableId = "tableId_example"; // String | The unique identifier of the table
try {
    BaseResponseOfTableDto result = apiInstance.getTableUsingGET(tableId);
    System.out.println(result);
} catch (ApiException e) {
    System.err.println("Exception when calling TableManagementApi#getTableUsingGET");
    e.printStackTrace();
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **tableId** | **String**| The unique identifier of the table |

### Return type

[**BaseResponseOfTableDto**](BaseResponseOfTableDto.md)

### Authorization

[oauth](../README.md#oauth)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

<a name="getTablesUsingGET"></a>
# **getTablesUsingGET**
> PagedResponseOfTableDto getTablesUsingGET(includeShared, limit, cursor, offset)

Retrieve a list of tables

Returns all tables available in the workspace.

### Example
```java
// Import classes:
//import io.swagger.client.ApiClient;
//import io.swagger.client.ApiException;
//import io.swagger.client.Configuration;
//import io.swagger.client.auth.*;
//import io.swagger.client.api.TableManagementApi;

ApiClient defaultClient = Configuration.getDefaultApiClient();

// Configure OAuth2 access token for authorization: oauth
OAuth oauth = (OAuth) defaultClient.getAuthentication("oauth");
oauth.setAccessToken("YOUR ACCESS TOKEN");

TableManagementApi apiInstance = new TableManagementApi();
Boolean includeShared = false; // Boolean | If true, returns all tables shared with the workspace associated with the request. If false, returns only tables the workspace owns.
Integer limit = 56; // Integer | the number of folders to return, from 1 to 1000; by default, 1000
String cursor = "cursor_example"; // String | a paging cursor; if included the limit is ignored
Long offset = 789L; // Long | The item to start with on the page, must be greater than or equal to 0, will default to 0
try {
    PagedResponseOfTableDto result = apiInstance.getTablesUsingGET(includeShared, limit, cursor, offset);
    System.out.println(result);
} catch (ApiException e) {
    System.err.println("Exception when calling TableManagementApi#getTablesUsingGET");
    e.printStackTrace();
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **includeShared** | **Boolean**| If true, returns all tables shared with the workspace associated with the request. If false, returns only tables the workspace owns. | [optional] [default to false]
 **limit** | **Integer**| the number of folders to return, from 1 to 1000; by default, 1000 | [optional]
 **cursor** | **String**| a paging cursor; if included the limit is ignored | [optional]
 **offset** | **Long**| The item to start with on the page, must be greater than or equal to 0, will default to 0 | [optional]

### Return type

[**PagedResponseOfTableDto**](PagedResponseOfTableDto.md)

### Authorization

[oauth](../README.md#oauth)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

<a name="importFileUsingPOST"></a>
# **importFileUsingPOST**
> BaseResponseOfFileMetaDto importFileUsingPOST(tableId, importDto)

Import a single file

Imports the provided file into the associated table, and immediately returns a file meta object with an ID that can be used to poll the file controller for status.

### Example
```java
// Import classes:
//import io.swagger.client.ApiClient;
//import io.swagger.client.ApiException;
//import io.swagger.client.Configuration;
//import io.swagger.client.auth.*;
//import io.swagger.client.api.TableManagementApi;

ApiClient defaultClient = Configuration.getDefaultApiClient();

// Configure OAuth2 access token for authorization: oauth
OAuth oauth = (OAuth) defaultClient.getAuthentication("oauth");
oauth.setAccessToken("YOUR ACCESS TOKEN");

TableManagementApi apiInstance = new TableManagementApi();
String tableId = "tableId_example"; // String | The unique identifier of the table
ImportDto importDto = new ImportDto(); // ImportDto | The representation of the table to import
try {
    BaseResponseOfFileMetaDto result = apiInstance.importFileUsingPOST(tableId, importDto);
    System.out.println(result);
} catch (ApiException e) {
    System.err.println("Exception when calling TableManagementApi#importFileUsingPOST");
    e.printStackTrace();
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **tableId** | **String**| The unique identifier of the table |
 **importDto** | [**ImportDto**](ImportDto.md)| The representation of the table to import |

### Return type

[**BaseResponseOfFileMetaDto**](BaseResponseOfFileMetaDto.md)

### Authorization

[oauth](../README.md#oauth)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

<a name="importFromSpreadsheetsUsingPOST"></a>
# **importFromSpreadsheetsUsingPOST**
> BaseResponseOfFileMetaDto importFromSpreadsheetsUsingPOST(tableId, importFromSpreadsheetDto)

Import from spreadsheets

Imports spreadsheet data and immediately returns a file meta result. This DTO has an ID, which can be used to poll on status via the file controller.

### Example
```java
// Import classes:
//import io.swagger.client.ApiClient;
//import io.swagger.client.ApiException;
//import io.swagger.client.Configuration;
//import io.swagger.client.auth.*;
//import io.swagger.client.api.TableManagementApi;

ApiClient defaultClient = Configuration.getDefaultApiClient();

// Configure OAuth2 access token for authorization: oauth
OAuth oauth = (OAuth) defaultClient.getAuthentication("oauth");
oauth.setAccessToken("YOUR ACCESS TOKEN");

TableManagementApi apiInstance = new TableManagementApi();
String tableId = "tableId_example"; // String | The unique identifier of the table
ImportFromSpreadsheetDto importFromSpreadsheetDto = new ImportFromSpreadsheetDto(); // ImportFromSpreadsheetDto | The representation of the table to update
try {
    BaseResponseOfFileMetaDto result = apiInstance.importFromSpreadsheetsUsingPOST(tableId, importFromSpreadsheetDto);
    System.out.println(result);
} catch (ApiException e) {
    System.err.println("Exception when calling TableManagementApi#importFromSpreadsheetsUsingPOST");
    e.printStackTrace();
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **tableId** | **String**| The unique identifier of the table |
 **importFromSpreadsheetDto** | [**ImportFromSpreadsheetDto**](ImportFromSpreadsheetDto.md)| The representation of the table to update |

### Return type

[**BaseResponseOfFileMetaDto**](BaseResponseOfFileMetaDto.md)

### Authorization

[oauth](../README.md#oauth)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

<a name="unimportFileUsingDELETE"></a>
# **unimportFileUsingDELETE**
> BaseResponseOfFileMetaDto unimportFileUsingDELETE(tableId, fileId, force)

Unimport a single file

Unimports the provided file from the provided table. Returns a 409 if the file is not in an imported state, or a 404 if the file can&#39;t be found.

### Example
```java
// Import classes:
//import io.swagger.client.ApiClient;
//import io.swagger.client.ApiException;
//import io.swagger.client.Configuration;
//import io.swagger.client.auth.*;
//import io.swagger.client.api.TableManagementApi;

ApiClient defaultClient = Configuration.getDefaultApiClient();

// Configure OAuth2 access token for authorization: oauth
OAuth oauth = (OAuth) defaultClient.getAuthentication("oauth");
oauth.setAccessToken("YOUR ACCESS TOKEN");

TableManagementApi apiInstance = new TableManagementApi();
String tableId = "tableId_example"; // String | The unique identifier of the table
String fileId = "fileId_example"; // String | The unique identifier of the file
String force = "false"; // String | If true, unimports and deletes file from the table
try {
    BaseResponseOfFileMetaDto result = apiInstance.unimportFileUsingDELETE(tableId, fileId, force);
    System.out.println(result);
} catch (ApiException e) {
    System.err.println("Exception when calling TableManagementApi#unimportFileUsingDELETE");
    e.printStackTrace();
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **tableId** | **String**| The unique identifier of the table |
 **fileId** | **String**| The unique identifier of the file |
 **force** | **String**| If true, unimports and deletes file from the table | [optional] [default to false]

### Return type

[**BaseResponseOfFileMetaDto**](BaseResponseOfFileMetaDto.md)

### Authorization

[oauth](../README.md#oauth)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

<a name="updateTableUsingPUT"></a>
# **updateTableUsingPUT**
> BaseResponseOfTableDto updateTableUsingPUT(tableDto, tableId)

Update a single table

Updates an existing table with the provided information. Include all user-defined table columns with the request. For type, specify either a dimension or data table. In the interface, data tables appear as fact tables.  * If the table has no imported data, user-defined columns not included with the request are deleted, and columns are sorted according to their order in the request.  * If the table has imported data, any columns with names not already in the table are considered new. This equality check is case-insensitive. Any new columns appear after other user-defined columns, but before any meta columns, which start with &#x60;_&#x60;.

### Example
```java
// Import classes:
//import io.swagger.client.ApiClient;
//import io.swagger.client.ApiException;
//import io.swagger.client.Configuration;
//import io.swagger.client.auth.*;
//import io.swagger.client.api.TableManagementApi;

ApiClient defaultClient = Configuration.getDefaultApiClient();

// Configure OAuth2 access token for authorization: oauth
OAuth oauth = (OAuth) defaultClient.getAuthentication("oauth");
oauth.setAccessToken("YOUR ACCESS TOKEN");

TableManagementApi apiInstance = new TableManagementApi();
TableDto tableDto = new TableDto(); // TableDto | The representation of the table to update
String tableId = "tableId_example"; // String | The unique identifier of the table
try {
    BaseResponseOfTableDto result = apiInstance.updateTableUsingPUT(tableDto, tableId);
    System.out.println(result);
} catch (ApiException e) {
    System.err.println("Exception when calling TableManagementApi#updateTableUsingPUT");
    e.printStackTrace();
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **tableDto** | [**TableDto**](TableDto.md)| The representation of the table to update |
 **tableId** | **String**| The unique identifier of the table |

### Return type

[**BaseResponseOfTableDto**](BaseResponseOfTableDto.md)

### Authorization

[oauth](../README.md#oauth)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

