# TagManagementApi

All URIs are relative to *https://h.app.wdesk.com/s/wdata/prep*

Method | HTTP request | Description
------------- | ------------- | -------------
[**createTagUsingPOST**](TagManagementApi.md#createTagUsingPOST) | **POST** /api/v1/tag | Create a new tag
[**deleteTagUsingDELETE**](TagManagementApi.md#deleteTagUsingDELETE) | **DELETE** /api/v1/tag/{tagId} | Delete a single tag
[**listTagsUsingGET**](TagManagementApi.md#listTagsUsingGET) | **GET** /api/v1/tag | Retrieve a list of tags
[**updateTagUsingPUT**](TagManagementApi.md#updateTagUsingPUT) | **PUT** /api/v1/tag/{tagId} | Update a single tag


<a name="createTagUsingPOST"></a>
# **createTagUsingPOST**
> BaseResponseOfTagDto createTagUsingPOST(tagDto)

Create a new tag

Creates a tag. If another tag already has the same key, returns a 409. There is a limit of 300 values for a tag.

### Example
```java
// Import classes:
//import io.swagger.client.ApiClient;
//import io.swagger.client.ApiException;
//import io.swagger.client.Configuration;
//import io.swagger.client.auth.*;
//import io.swagger.client.api.TagManagementApi;

ApiClient defaultClient = Configuration.getDefaultApiClient();

// Configure OAuth2 access token for authorization: oauth
OAuth oauth = (OAuth) defaultClient.getAuthentication("oauth");
oauth.setAccessToken("YOUR ACCESS TOKEN");

TagManagementApi apiInstance = new TagManagementApi();
TagDto tagDto = new TagDto(); // TagDto | The representation of the tag to create
try {
    BaseResponseOfTagDto result = apiInstance.createTagUsingPOST(tagDto);
    System.out.println(result);
} catch (ApiException e) {
    System.err.println("Exception when calling TagManagementApi#createTagUsingPOST");
    e.printStackTrace();
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **tagDto** | [**TagDto**](TagDto.md)| The representation of the tag to create |

### Return type

[**BaseResponseOfTagDto**](BaseResponseOfTagDto.md)

### Authorization

[oauth](../README.md#oauth)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

<a name="deleteTagUsingDELETE"></a>
# **deleteTagUsingDELETE**
> BaseResponseOfstring deleteTagUsingDELETE(tagId)

Delete a single tag

Deletes the tag with the provided ID. If no such tag is found, this is a no-op.

### Example
```java
// Import classes:
//import io.swagger.client.ApiClient;
//import io.swagger.client.ApiException;
//import io.swagger.client.Configuration;
//import io.swagger.client.auth.*;
//import io.swagger.client.api.TagManagementApi;

ApiClient defaultClient = Configuration.getDefaultApiClient();

// Configure OAuth2 access token for authorization: oauth
OAuth oauth = (OAuth) defaultClient.getAuthentication("oauth");
oauth.setAccessToken("YOUR ACCESS TOKEN");

TagManagementApi apiInstance = new TagManagementApi();
String tagId = "tagId_example"; // String | The unique identifier of the tag
try {
    BaseResponseOfstring result = apiInstance.deleteTagUsingDELETE(tagId);
    System.out.println(result);
} catch (ApiException e) {
    System.err.println("Exception when calling TagManagementApi#deleteTagUsingDELETE");
    e.printStackTrace();
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **tagId** | **String**| The unique identifier of the tag |

### Return type

[**BaseResponseOfstring**](BaseResponseOfstring.md)

### Authorization

[oauth](../README.md#oauth)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

<a name="listTagsUsingGET"></a>
# **listTagsUsingGET**
> PagedResponseOfTagDto listTagsUsingGET(limit, cursor, offset)

Retrieve a list of tags

Returns a paged list of all tags associated with the workspace of the request.

### Example
```java
// Import classes:
//import io.swagger.client.ApiClient;
//import io.swagger.client.ApiException;
//import io.swagger.client.Configuration;
//import io.swagger.client.auth.*;
//import io.swagger.client.api.TagManagementApi;

ApiClient defaultClient = Configuration.getDefaultApiClient();

// Configure OAuth2 access token for authorization: oauth
OAuth oauth = (OAuth) defaultClient.getAuthentication("oauth");
oauth.setAccessToken("YOUR ACCESS TOKEN");

TagManagementApi apiInstance = new TagManagementApi();
Integer limit = 56; // Integer | The number of tags to return, from 1 to 1000; by default, 1000
String cursor = "cursor_example"; // String | A paging cursor; if included, `limit` is ignored
Long offset = 789L; // Long | The item to start with on the page, greater than or equal to 0; by default, 0
try {
    PagedResponseOfTagDto result = apiInstance.listTagsUsingGET(limit, cursor, offset);
    System.out.println(result);
} catch (ApiException e) {
    System.err.println("Exception when calling TagManagementApi#listTagsUsingGET");
    e.printStackTrace();
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **limit** | **Integer**| The number of tags to return, from 1 to 1000; by default, 1000 | [optional]
 **cursor** | **String**| A paging cursor; if included, &#x60;limit&#x60; is ignored | [optional]
 **offset** | **Long**| The item to start with on the page, greater than or equal to 0; by default, 0 | [optional]

### Return type

[**PagedResponseOfTagDto**](PagedResponseOfTagDto.md)

### Authorization

[oauth](../README.md#oauth)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

<a name="updateTagUsingPUT"></a>
# **updateTagUsingPUT**
> BaseResponseOfTagDto updateTagUsingPUT(tagId, tagDto)

Update a single tag

Updates the tag that matches the provided ID with the details provided in the body. Ignores the provided key, as keys are immutable once set. There is a limit of 300 values for a tag. 

### Example
```java
// Import classes:
//import io.swagger.client.ApiClient;
//import io.swagger.client.ApiException;
//import io.swagger.client.Configuration;
//import io.swagger.client.auth.*;
//import io.swagger.client.api.TagManagementApi;

ApiClient defaultClient = Configuration.getDefaultApiClient();

// Configure OAuth2 access token for authorization: oauth
OAuth oauth = (OAuth) defaultClient.getAuthentication("oauth");
oauth.setAccessToken("YOUR ACCESS TOKEN");

TagManagementApi apiInstance = new TagManagementApi();
String tagId = "tagId_example"; // String | The unique identifier of the tag
TagDto tagDto = new TagDto(); // TagDto | The representation of the tag to update
try {
    BaseResponseOfTagDto result = apiInstance.updateTagUsingPUT(tagId, tagDto);
    System.out.println(result);
} catch (ApiException e) {
    System.err.println("Exception when calling TagManagementApi#updateTagUsingPUT");
    e.printStackTrace();
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **tagId** | **String**| The unique identifier of the tag |
 **tagDto** | [**TagDto**](TagDto.md)| The representation of the tag to update |

### Return type

[**BaseResponseOfTagDto**](BaseResponseOfTagDto.md)

### Authorization

[oauth](../README.md#oauth)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

